@@ -98,6 +98,7 @@ void zhttp_free(struct zhttp *http){
 	zhttp_post_free(http);
 	g_free(http->datastr);
 	if (http->connecting_timer_id > 0) zselect_timer_kill(http->zsel, http->connecting_timer_id);
+	if (http->watchdog_timer_id > 0) zselect_timer_kill(http->zsel, http->watchdog_timer_id);
 	g_free(http);
 }
 
@@ -519,11 +520,36 @@ static void zhttp_connecting_timer(void *arg){
 	zhttp_disconnect(http, g_strdup_printf("Timeout connecting to %s:%d", http->server, http->port));
 }
 
+static void zhttp_watchdog_timer(void* arg) {
+	struct zhttp* http = (struct zhttp*)arg;
+
+	if (http->watchdog_flag == 0) {
+		http->watchdog_timer_id = -1;
+		zhttp_disconnect(http, g_strdup_printf("Timeout during transfer %s:%d", http->server, http->port));
+		return;
+	}
+
+	http->watchdog_flag = 0;
+	http->watchdog_timer_id = zselect_timer_new(http->zsel, 30000, zhttp_watchdog_timer, http);
+
+}
+
 static void zhttp_connected_handler(void *arg){
     struct zhttp *http = (struct zhttp *)arg;
 	char errbuf[256];
 
-	if (z_sock_error(http->sock)){
+	if (http->connecting_timer_id > 0) {
+		zselect_timer_kill(http->zsel, http->connecting_timer_id);
+		http->connecting_timer_id = -1;
+	}
+
+	http->watchdog_flag = 0;
+	http->watchdog_timer_id = zselect_timer_new(http->zsel, 30000, zhttp_watchdog_timer, http);
+
+
+
+	int err = z_sock_error(http->sock);
+	if (err){
         zhttp_disconnect(http, g_strdup_printf("Can't connect to %s:%d, %s", http->server, http->port, z_sock_strerror()));
         return;
     }
@@ -682,6 +708,7 @@ static void zhttp_write_handler(void *arg){
 #endif
 	{
 		ret = send(http->sock, http->request->buf, tosend, 0);
+		int err = z_sock_errno;
 		if (ret <= 0){
 			zhttp_disconnect(http, g_strdup_printf("Error writing http socket: %s", z_sock_strerror()));
 			return;
@@ -690,7 +717,7 @@ static void zhttp_write_handler(void *arg){
 
     //dbg("send(%d) = %d\n", tosend, ret);
 	
-
+	http->watchdog_flag = 1;
 	http->sent += ret;
 
     //dbg("buf=%d -> ", http->request->len);
@@ -778,6 +805,7 @@ static void zhttp_read_handler(void *arg){
 #endif
 	{
 		ret = recv(http->sock, buf, torecv, 0);
+		int err = z_sock_errno;
 		if (ret < 0){
 			zhttp_disconnect(http, g_strdup_printf("Error reading http socket: %s", z_sock_strerror()));
 			return;
@@ -830,6 +858,7 @@ static void zhttp_read_handler(void *arg){
 		return;
 	}
 
+	http->watchdog_flag = 1;
 	zbinbuf_append_bin(http->response, buf, ret);
 
 	if (http->dataofs < 0){
