@@ -123,8 +123,9 @@ struct zzsdl *zsdl_init(SDL_Surface *screen, int font_h, int inverse, SDL_RWops*
     if (zsdl->ttf_iconv == (iconv_t)-1) zinternal("Can't create TTF iconv object UTF-8 to ISO8859-2");
 
 #endif
-    zsdl->pxformat = screen->format;
-
+	//zsdl->format = SDL_GetWindowPixelFormat(screen);
+    //zsdl->pxformat = SDL_AllocFormat(zsdl->format);
+    //dbg("zsdl_init  format=%s  RMask=%x  GMask=%x  BMask=%x  AMask=%x\n", SDL_GetPixelFormatName(zsdl->format), zsdl->pxformat->Rmask, zsdl->pxformat->Gmask, zsdl->pxformat->Bmask, zsdl->pxformat->Amask);
 	outline9x16 = zfont_create_outline(font9x16, sizeof(font9x16), 16);
 
     //zsdl_font_save(screen);
@@ -577,6 +578,8 @@ int zsdl_print_ttf_char(SDL_Surface* surface, int *x, int y, int color, int bgco
         r.h *= 2;
         r.y -= zsdl->font_h;
         SDL_BlitScaled(src, NULL, surface, &r);
+    }else if (flags & ZFONT_USERHFLG) {
+        SDL_BlitScaled(src, NULL, surface, &r);
     }else{
         SDL_BlitSurface(src, NULL, surface, &r);
     }
@@ -1570,10 +1573,6 @@ int zsdl_sys_key_repeat(int delay, int rate){
 
 #endif
 
-#ifdef Z_ANDROID
-    void SDL_ANDROID_DisableScreensaver(void);
-#endif
-
 void z_disable_screensaver(void){
 #ifdef Z_MSC_MINGW
 	int ret;
@@ -1629,7 +1628,7 @@ void z_disable_screensaver(void){
     }
 #endif
 #ifdef Z_ANDROID
-    SDL_ANDROID_DisableScreensaver();
+    //The screensaver is disabled by default since SDL 2.0.2.
 #endif
 }
 
